#!/bin/bash
VERSION=v5
CPU=7450
TARGET=powerpc-${CPU}-linux-gnu
LINUX_VERSION=2.6.27.62 #2.6.32.27 #3.0.4 #3.2.60 #3.4.97 #3.8.13 #3.14.11 #2.6.27.62
BUSYBOX_VERSION=1.21.1
GENEXT2FS_VERSION=1.4.1
INITRD_SIZE=16384 # max 32768 KB or reconfigure the linux kernel
NUM_PROCESSORS=$(cat /proc/cpuinfo | cut -f 1 | grep vendor_id | wc -l)
HERE=$(pwd)
MY_DIR=$(cd $(dirname $0); pwd)
KERNELDIR=${MY_DIR}/linux-${LINUX_VERSION}

TARBALLS_DIR=${MY_DIR}/downloads
INITRD_IMG=initrd.img
VMLINUX=vmlinux
INITRD_DIR=${MY_DIR}/initrd
SCRIPTS_DIR=${MY_DIR}/scripts

Usage ()
{
	echo "Usage: $0 <command> [<path-to-prebuilt-miBench-dir>] [<path-to-cross-compiler>]"
	echo "  command set:"
	echo "     all          build everything"
	echo "     clean        clean everything"
	echo "     dist-bin     tar all binaries and data sets in a unique tarball"
	echo "     dist-source  tar all sources in a unique tarball"
	echo "  path-to-precompiled-miBench-dir:"
	echo "     Path to directory containing prebuilt MiBench version 1 benchmarks"
	echo "     (e.g. \${HOME}/mibench-v1-bin-\${TARGET}-v1)"
	echo "  path-to-cross-compiler:"
	echo "     Path to directory of gcc C/C++ cross-compiler for ${TARGET}"
	echo "     either as argument or into environment variable POWERPC_CROSS_COMPILER_PREFIX"
	echo "     (e.g. /opt/crosstool/gcc-4.4.6-glibc-2.9/${TARGET})"
	echo "     Use crosstool-0.43 or preferably crosstool-ng to get a working cross compiler."
}

CMD="$1"
case "${CMD}" in
	all)
		MIBENCH_BUILD_DIR="$2"
		if ! [ -d "${MIBENCH_BUILD_DIR}" ] || ! [ -d "${MIBENCH_BUILD_DIR}/automotive" ]; then
			echo "FATAL: Can't find prebuilt MiBench version 1 benchmarks"
			Usage
			exit 255
		fi
		if [ -z "${POWERPC_CROSS_COMPILER_PREFIX}" ]; then
			if [ -z "$2" ]; then
				echo "FATAL: Please specify path to cross-compiler"
				Usage
				exit 255
			fi
			POWERPC_CROSS_COMPILER_PREFIX="$3"
		fi
		;;
	dist-bin)
		FILE_LIST="\
		${VMLINUX} \
		initrd_automotive_basicmath_large.img \
		initrd_automotive_basicmath_small.img \
		initrd_automotive_bitcount_large.img \
		initrd_automotive_bitcount_small.img \
		initrd_automotive_qsort_large.img \
		initrd_automotive_qsort_small.img \
		initrd_automotive_susan_large.img \
		initrd_automotive_susan_small.img \
		initrd_consumer_jpeg_large.img \
		initrd_consumer_jpeg_small.img \
		initrd_consumer_lame_large.img \
		initrd_consumer_lame_small.img \
		initrd_consumer_mad_large.img \
		initrd_consumer_mad_small.img \
		initrd_consumer_tiff2bw_large.img \
		initrd_consumer_tiff2bw_small.img \
		initrd_consumer_tiff2rgba_large.img \
		initrd_consumer_tiff2rgba_small.img \
		initrd_consumer_tiffdither_large.img \
		initrd_consumer_tiffdither_small.img \
		initrd_consumer_tiffmedian_large.img \
		initrd_consumer_tiffmedian_small.img \
		initrd_consumer_typeset_large.img \
		initrd_consumer_typeset_small.img \
		initrd.img \
		initrd_network_dijkstra_large.img \
		initrd_network_dijkstra_small.img \
		initrd_network_patricia_large.img \
		initrd_network_patricia_small.img \
		initrd_office_rsynth_large.img \
		initrd_office_rsynth_small.img \
		initrd_office_sphinx.img \
		initrd_office_stringsearch_large.img \
		initrd_office_stringsearch_small.img \
		initrd_security_blowfish_large.img \
		initrd_security_blowfish_small.img \
		initrd_security_pgp.img \
		initrd_security_rijndael_large.img \
		initrd_security_rijndael_small.img \
		initrd_security_sha_large.img \
		initrd_security_sha_small.img \
		initrd_telecomm_adpcm_large.img \
		initrd_telecomm_adpcm_small.img \
		initrd_telecomm_crc32_large.img \
		initrd_telecomm_crc32_small.img \
		initrd_telecomm_fft_large.img \
		initrd_telecomm_fft_small.img \
		initrd_telecomm_gsm_large.img \
		initrd_telecomm_gsm_small.img \
		busybox-${BUSYBOX_VERSION}/busybox_unstripped \
		config/sim_config_automotive_basicmath_large.xml \
		config/sim_config_automotive_basicmath_small.xml \
		config/sim_config_automotive_basicmath.xml \
		config/sim_config_automotive_bitcount_large.xml \
		config/sim_config_automotive_bitcount_small.xml \
		config/sim_config_automotive_bitcount.xml \
		config/sim_config_automotive_qsort_large.xml \
		config/sim_config_automotive_qsort_small.xml \
		config/sim_config_automotive_qsort.xml \
		config/sim_config_automotive_susan_large.xml \
		config/sim_config_automotive_susan_small.xml \
		config/sim_config_automotive_susan.xml \
		config/sim_config_consumer_jpeg_large.xml \
		config/sim_config_consumer_jpeg_small.xml \
		config/sim_config_consumer_jpeg.xml \
		config/sim_config_consumer_lame_large.xml \
		config/sim_config_consumer_lame_small.xml \
		config/sim_config_consumer_lame.xml \
		config/sim_config_consumer_mad_large.xml \
		config/sim_config_consumer_mad_small.xml \
		config/sim_config_consumer_tiff2bw_large.xml \
		config/sim_config_consumer_tiff2bw_small.xml \
		config/sim_config_consumer_tiff2rgba_large.xml \
		config/sim_config_consumer_tiff2rgba_small.xml \
		config/sim_config_consumer_tiffdither_large.xml \
		config/sim_config_consumer_tiffdither_small.xml \
		config/sim_config_consumer_tiffmedian_large.xml \
		config/sim_config_consumer_tiffmedian_small.xml \
		config/sim_config_consumer_typeset_large.xml \
		config/sim_config_consumer_typeset_small.xml \
		config/sim_config_consumer_typeset.xml \
		config/sim_config_network_dijkstra_large.xml \
		config/sim_config_network_dijkstra_small.xml \
		config/sim_config_network_dijkstra.xml \
		config/sim_config_network_patricia_large.xml \
		config/sim_config_network_patricia_small.xml \
		config/sim_config_network_patricia.xml \
		config/sim_config_office_ghostscript_large.xml \
		config/sim_config_office_ghostscript_small.xml \
		config/sim_config_office_ghostscript.xml \
		config/sim_config_office_ispell_large.xml \
		config/sim_config_office_ispell_small.xml \
		config/sim_config_office_ispell.xml \
		config/sim_config_office_rsynth_large.xml \
		config/sim_config_office_rsynth_small.xml \
		config/sim_config_office_sphinx.xml \
		config/sim_config_office_stringsearch_large.xml \
		config/sim_config_office_stringsearch_small.xml \
		config/sim_config_office_stringsearch.xml \
		config/sim_config_security_blowfish_large.xml \
		config/sim_config_security_blowfish_small.xml \
		config/sim_config_security_blowfish.xml \
		config/sim_config_security_pgp.xml \
		config/sim_config_security_rijndael_large.xml \
		config/sim_config_security_rijndael_small.xml \
		config/sim_config_security_rijndael.xml \
		config/sim_config_security_sha_large.xml \
		config/sim_config_security_sha_small.xml \
		config/sim_config_security_sha.xml \
		config/sim_config_telecomm_adpcm_large.xml \
		config/sim_config_telecomm_adpcm_small.xml \
		config/sim_config_telecomm_adpcm.xml \
		config/sim_config_telecomm_crc32_large.xml \
		config/sim_config_telecomm_crc32_small.xml \
		config/sim_config_telecomm_crc32.xml \
		config/sim_config_telecomm_fft_large.xml \
		config/sim_config_telecomm_fft_small.xml \
		config/sim_config_telecomm_fft.xml \
		config/sim_config_telecomm_gsm_large.xml \
		config/sim_config_telecomm_gsm_small.xml \
		config/sim_config_telecomm_gsm.xml \
		config/sim_config.xml \
		config/automotive_basicmath_large.debug.mac \
		config/automotive_basicmath_small.debug.mac \
		config/automotive_bitcount_large.debug.mac \
		config/automotive_bitcount_small.debug.mac \
		config/automotive_qsort_large.debug.mac \
		config/automotive_qsort_small.debug.mac \
		config/automotive_susan_large.debug.mac \
		config/automotive_susan_small.debug.mac \
		config/consumer_jpeg_large.debug.mac \
		config/consumer_jpeg_small.debug.mac \
		config/consumer_lame_large.debug.mac \
		config/consumer_lame_small.debug.mac \
		config/consumer_mad_large.debug.mac \
		config/consumer_mad_small.debug.mac \
		config/consumer_tiff2bw_large.debug.mac \
		config/consumer_tiff2bw_small.debug.mac \
		config/consumer_tiff2rgba_large.debug.mac \
		config/consumer_tiff2rgba_small.debug.mac \
		config/consumer_tiffdither_large.debug.mac \
		config/consumer_tiffdither_small.debug.mac \
		config/consumer_tiffmedian_large.debug.mac \
		config/consumer_tiffmedian_small.debug.mac \
		config/consumer_typeset_large.debug.mac \
		config/consumer_typeset_small.debug.mac \
		config/network_dijkstra_large.debug.mac \
		config/network_dijkstra_small.debug.mac \
		config/network_patricia_large.debug.mac \
		config/network_patricia_small.debug.mac \
		config/office_ghostscript_large.debug.mac \
		config/office_ghostscript_small.debug.mac \
		config/office_ispell_large.debug.mac \
		config/office_ispell_small.debug.mac \
		config/office_rsynth_large.debug.mac \
		config/office_rsynth_small.debug.mac \
		config/office_sphinx.debug.mac \
		config/office_stringsearch_large.debug.mac \
		config/office_stringsearch_small.debug.mac \
		config/security_blowfish_large.debug.mac \
		config/security_blowfish_small.debug.mac \
		config/security_pgp.debug.mac \
		config/security_rijndael_large.debug.mac \
		config/security_rijndael_small.debug.mac \
		config/security_sha_large.debug.mac \
		config/security_sha_small.debug.mac \
		config/telecomm_adpcm_large.debug.mac \
		config/telecomm_adpcm_small.debug.mac \
		config/telecomm_crc32_large.debug.mac \
		config/telecomm_crc32_small.debug.mac \
		config/telecomm_fft_large.debug.mac \
		config/telecomm_fft_small.debug.mac \
		config/telecomm_gsm_large.debug.mac \
		config/telecomm_gsm_small.debug.mac \
		"

		PKG_NAME="unisim-ppcemu-system-linux-distro-bin-${VERSION}"

		rm -rf ${HERE}/${PKG_NAME}
		rm -f ${HERE}/${PKG_NAME}.tar.gz
		mkdir -p ${HERE}/${PKG_NAME}

		for FILE in ${FILE_LIST}; do
			mkdir -p ${HERE}/${PKG_NAME}/$(dirname ${FILE})
			cp ${MY_DIR}/${FILE} ${HERE}/${PKG_NAME}/${FILE} || exit 255
		done

		cat << EOF > "${HERE}/${PKG_NAME}/README"
This package provides a mini Linux distribution based on Busybox and the MiBench version 1 benchmarks.
The package contains:
- a prebuilt Linux kernel image (${VMLINUX})
- configuration files for the UNISIM ppcemu-system Simulator (1.0beta3+) (config/sim_config*.xml)
- the debug macro files to automatically load symbols of debugged benchmarks at simulator startup (config/*.debug.mac)
- prebuilt initial RAM disk images (*.img) that themselves contain:
    - busybox
    - prebuilt binaries of MiBench version 1 (http://www.eecs.umich.edu/mibench) for target ${TARGET}
    - the original MiBench version 1 datasets and scripts to run each benchmark on the native target
EOF
		cd ${HERE}
		tar zcvf ${HERE}/${PKG_NAME}.tar.gz ${PKG_NAME}
		rm -rf ${HERE}/${PKG_NAME}
		;;
	dist-source)
		FILE_LIST="\
		downloads/busybox-${BUSYBOX_VERSION}.tar.bz2 \
		downloads/linux-${LINUX_VERSION}.tar.bz2 \
		downloads/genext2fs-${GENEXT2FS_VERSION}.tar.gz \
		config/busybox-${BUSYBOX_VERSION}-config \
		config/linux-${LINUX_VERSION}-config \
		patches/patch-i8042-drv-${LINUX_VERSION} \
		patches/patch-nap-mode-${LINUX_VERSION} \
		patches/patch-offb-setcolreg-${LINUX_VERSION} \
		scripts/mkcompile_h \
		scripts/init_automotive_basicmath_large.sh \
		scripts/init_automotive_basicmath_small.sh \
		scripts/init_automotive_bitcount_large.sh \
		scripts/init_automotive_bitcount_small.sh \
		scripts/init_automotive_qsort_large.sh \
		scripts/init_automotive_qsort_small.sh \
		scripts/init_automotive_susan_large.sh \
		scripts/init_automotive_susan_small.sh \
		scripts/init_consumer_jpeg_large.sh \
		scripts/init_consumer_jpeg_small.sh \
		scripts/init_consumer_lame_large.sh \
		scripts/init_consumer_lame_small.sh \
		scripts/init_consumer_mad_large.sh \
		scripts/init_consumer_mad_small.sh \
		scripts/init_consumer_tiff2bw_large.sh \
		scripts/init_consumer_tiff2bw_small.sh \
		scripts/init_consumer_tiff2rgba_large.sh \
		scripts/init_consumer_tiff2rgba_small.sh \
		scripts/init_consumer_tiffdither_large.sh \
		scripts/init_consumer_tiffdither_small.sh \
		scripts/init_consumer_tiffmedian_large.sh \
		scripts/init_consumer_tiffmedian_small.sh \
		scripts/init_consumer_typeset_large.sh \
		scripts/init_consumer_typeset_small.sh \
		scripts/init_network_dijkstra_large.sh \
		scripts/init_network_dijkstra_small.sh \
		scripts/init_network_patricia_large.sh \
		scripts/init_network_patricia_small.sh \
		scripts/init_office_ghostscript_large.sh \
		scripts/init_office_ghostscript_small.sh \
		scripts/init_office_ispell_large.sh \
		scripts/init_office_ispell_small.sh \
		scripts/init_office_rsynth_large.sh \
		scripts/init_office_rsynth_small.sh \
		scripts/init_office_sphinx.sh \
		scripts/init_office_stringsearch_large.sh \
		scripts/init_office_stringsearch_small.sh \
		scripts/init_security_blowfish_large.sh \
		scripts/init_security_blowfish_small.sh \
		scripts/init_security_pgp.sh \
		scripts/init_security_rijndael_large.sh \
		scripts/init_security_rijndael_small.sh \
		scripts/init_security_sha_large.sh \
		scripts/init_security_sha_small.sh \
		scripts/init.sh \
		scripts/init_telecomm_adpcm_large.sh \
		scripts/init_telecomm_adpcm_small.sh \
		scripts/init_telecomm_crc32_large.sh \
		scripts/init_telecomm_crc32_small.sh \
		scripts/init_telecomm_fft_large.sh \
		scripts/init_telecomm_fft_small.sh \
		scripts/init_telecomm_gsm_large.sh \
		scripts/init_telecomm_gsm_small.sh \
		scripts/inittab \
		scripts/rcS \
		config/device_table.txt \
		config/sim_config_automotive_basicmath_large.xml \
		config/sim_config_automotive_basicmath_small.xml \
		config/sim_config_automotive_basicmath.xml \
		config/sim_config_automotive_bitcount_large.xml \
		config/sim_config_automotive_bitcount_small.xml \
		config/sim_config_automotive_bitcount.xml \
		config/sim_config_automotive_qsort_large.xml \
		config/sim_config_automotive_qsort_small.xml \
		config/sim_config_automotive_qsort.xml \
		config/sim_config_automotive_susan_large.xml \
		config/sim_config_automotive_susan_small.xml \
		config/sim_config_automotive_susan.xml \
		config/sim_config_consumer_jpeg_large.xml \
		config/sim_config_consumer_jpeg_small.xml \
		config/sim_config_consumer_jpeg.xml \
		config/sim_config_consumer_lame_large.xml \
		config/sim_config_consumer_lame_small.xml \
		config/sim_config_consumer_lame.xml \
		config/sim_config_consumer_mad_large.xml \
		config/sim_config_consumer_mad_small.xml \
		config/sim_config_consumer_tiff2bw_large.xml \
		config/sim_config_consumer_tiff2bw_small.xml \
		config/sim_config_consumer_tiff2rgba_large.xml \
		config/sim_config_consumer_tiff2rgba_small.xml \
		config/sim_config_consumer_tiffdither_large.xml \
		config/sim_config_consumer_tiffdither_small.xml \
		config/sim_config_consumer_tiffmedian_large.xml \
		config/sim_config_consumer_tiffmedian_small.xml \
		config/sim_config_consumer_typeset_large.xml \
		config/sim_config_consumer_typeset_small.xml \
		config/sim_config_consumer_typeset.xml \
		config/sim_config_network_dijkstra_large.xml \
		config/sim_config_network_dijkstra_small.xml \
		config/sim_config_network_dijkstra.xml \
		config/sim_config_network_patricia_large.xml \
		config/sim_config_network_patricia_small.xml \
		config/sim_config_network_patricia.xml \
		config/sim_config_office_ghostscript_large.xml \
		config/sim_config_office_ghostscript_small.xml \
		config/sim_config_office_ghostscript.xml \
		config/sim_config_office_ispell_large.xml \
		config/sim_config_office_ispell_small.xml \
		config/sim_config_office_ispell.xml \
		config/sim_config_office_rsynth_large.xml \
		config/sim_config_office_rsynth_small.xml \
		config/sim_config_office_sphinx.xml \
		config/sim_config_office_stringsearch_large.xml \
		config/sim_config_office_stringsearch_small.xml \
		config/sim_config_office_stringsearch.xml \
		config/sim_config_security_blowfish_large.xml \
		config/sim_config_security_blowfish_small.xml \
		config/sim_config_security_blowfish.xml \
		config/sim_config_security_pgp.xml \
		config/sim_config_security_rijndael_large.xml \
		config/sim_config_security_rijndael_small.xml \
		config/sim_config_security_rijndael.xml \
		config/sim_config_security_sha_large.xml \
		config/sim_config_security_sha_small.xml \
		config/sim_config_security_sha.xml \
		config/sim_config_telecomm_adpcm_large.xml \
		config/sim_config_telecomm_adpcm_small.xml \
		config/sim_config_telecomm_adpcm.xml \
		config/sim_config_telecomm_crc32_large.xml \
		config/sim_config_telecomm_crc32_small.xml \
		config/sim_config_telecomm_crc32.xml \
		config/sim_config_telecomm_fft_large.xml \
		config/sim_config_telecomm_fft_small.xml \
		config/sim_config_telecomm_fft.xml \
		config/sim_config_telecomm_gsm_large.xml \
		config/sim_config_telecomm_gsm_small.xml \
		config/sim_config_telecomm_gsm.xml \
		config/sim_config.xml \
		config/automotive_basicmath_large.debug.mac \
		config/automotive_basicmath_small.debug.mac \
		config/automotive_bitcount_large.debug.mac \
		config/automotive_bitcount_small.debug.mac \
		config/automotive_qsort_large.debug.mac \
		config/automotive_qsort_small.debug.mac \
		config/automotive_susan_large.debug.mac \
		config/automotive_susan_small.debug.mac \
		config/consumer_jpeg_large.debug.mac \
		config/consumer_jpeg_small.debug.mac \
		config/consumer_lame_large.debug.mac \
		config/consumer_lame_small.debug.mac \
		config/consumer_mad_large.debug.mac \
		config/consumer_mad_small.debug.mac \
		config/consumer_tiff2bw_large.debug.mac \
		config/consumer_tiff2bw_small.debug.mac \
		config/consumer_tiff2rgba_large.debug.mac \
		config/consumer_tiff2rgba_small.debug.mac \
		config/consumer_tiffdither_large.debug.mac \
		config/consumer_tiffdither_small.debug.mac \
		config/consumer_tiffmedian_large.debug.mac \
		config/consumer_tiffmedian_small.debug.mac \
		config/consumer_typeset_large.debug.mac \
		config/consumer_typeset_small.debug.mac \
		config/network_dijkstra_large.debug.mac \
		config/network_dijkstra_small.debug.mac \
		config/network_patricia_large.debug.mac \
		config/network_patricia_small.debug.mac \
		config/office_ghostscript_large.debug.mac \
		config/office_ghostscript_small.debug.mac \
		config/office_ispell_large.debug.mac \
		config/office_ispell_small.debug.mac \
		config/office_rsynth_large.debug.mac \
		config/office_rsynth_small.debug.mac \
		config/office_sphinx.debug.mac \
		config/office_stringsearch_large.debug.mac \
		config/office_stringsearch_small.debug.mac \
		config/security_blowfish_large.debug.mac \
		config/security_blowfish_small.debug.mac \
		config/security_pgp.debug.mac \
		config/security_rijndael_large.debug.mac \
		config/security_rijndael_small.debug.mac \
		config/security_sha_large.debug.mac \
		config/security_sha_small.debug.mac \
		config/telecomm_adpcm_large.debug.mac \
		config/telecomm_adpcm_small.debug.mac \
		config/telecomm_crc32_large.debug.mac \
		config/telecomm_crc32_small.debug.mac \
		config/telecomm_fft_large.debug.mac \
		config/telecomm_fft_small.debug.mac \
		config/telecomm_gsm_large.debug.mac \
		config/telecomm_gsm_small.debug.mac \
		$(basename $0) \
		"

		PKG_NAME="unisim-ppcemu-system-linux-distro-source-${VERSION}"

		rm -rf ${HERE}/${PKG_NAME}
		rm -f ${HERE}/${PKG_NAME}.tar.gz
		mkdir -p ${HERE}/${PKG_NAME}

		for FILE in ${FILE_LIST}; do
			mkdir -p ${HERE}/${PKG_NAME}/$(dirname ${FILE})
			cp ${MY_DIR}/${FILE} ${HERE}/${PKG_NAME}/${FILE} || exit 255
		done

		cat << EOF > "${HERE}/${PKG_NAME}/README"
This package provides the source code of a mini Linux distribution based on Busybox and the MiBench version 1 benchmarks.

Requirements:
- A Linux host machine with a decent installation of development packages

This package contains:
- the source of the boot program for the UNISIM ppcemu-system Simulator (1.0beta3+)
- the original Linux kernel source tarball (downloads/linux*.tar.gz)
- the original Busybox source tarball (downloads/busybox*.tar.gz)
- the device trees for the UNISIM ppcemu-system Simulator (1.0beta3+) (config/*.dts)
- the patches to make the Linux kernel and Busybox run on the UNISIM ppcemu-system Simulator (1.0beta3+)
- the init scripts of initial RAM disks (scripts/*)
- the configuration files for building the Linux kernel and Busybox
- the configuration files for the UNISIM ppcemu-system Simulator (1.0beta3+) (config/sim_config*.xml)
- the debug macro files to automatically load symbols of debugged benchmarks at simulator startup (config/*.debug.mac)
EOF
		cd ${HERE}
		tar zcvf ${HERE}/${PKG_NAME}.tar.gz ${PKG_NAME}
		rm -rf ${HERE}/${PKG_NAME}
		;;
	clean)
		;;
	*)
		echo "FATAL: Please specify a command"
		Usage
		exit 255
		;;
esac

mkdir -p ${TARBALLS_DIR}

################################################################################
#                               LINUX KERNEL                                   #
################################################################################

LINUX_CONFIG=${MY_DIR}/config/linux-${LINUX_VERSION}-config
MKCOMPILE_H=${MY_DIR}/scripts/mkcompile_h
LINUX_PATCH_I8042_DRV=${MY_DIR}/patches/patch-i8042-drv-${LINUX_VERSION}
LINUX_PATCH_NAP_MODE=${MY_DIR}/patches/patch-nap-mode-${LINUX_VERSION}
LINUX_PATCH_OFFB_SETCOLREG=${MY_DIR}/patches/patch-offb-setcolreg-${LINUX_VERSION}

case "${CMD}" in
	all)

		if [ ! -e ${TARBALLS_DIR}/linux-${LINUX_VERSION}.tar.bz2 ]; then
			echo "Downloading Linux kernel source tarball. Please wait..."
			wget https://www.kernel.org/pub/linux/kernel/v2.6/linux-${LINUX_VERSION}.tar.bz2 -P ${TARBALLS_DIR}
			if [ $? -ne 0 ]; then
				echo "Downloading Linux kernel source tarball failed"
				exit 255
			fi
		fi

		if [ ! -d linux-${LINUX_VERSION} ]; then
			echo "Uncompressing Linux kernel source tarball. Please wait..."
			tar xvf ${TARBALLS_DIR}/linux-${LINUX_VERSION}.tar.bz2
			cp -f ${LINUX_CONFIG} linux-${LINUX_VERSION}/.config
			cp -f ${MKCOMPILE_H} ${MY_DIR}/linux-${LINUX_VERSION}/scripts/mkcompile_h
			cd linux-${LINUX_VERSION}
			if [ -f "${LINUX_PATCH_I8042_DRV}" ]; then
				echo "Patching i8042 driver. Please wait..."
				patch -p1 < ${LINUX_PATCH_I8042_DRV}
			fi
			if [ -f "${LINUX_PATCH_NAP_MODE}" ]; then
				echo "Patching kernel to enable powersave NAP mode. Please wait..."
				patch -p1 < ${LINUX_PATCH_NAP_MODE}
			fi
			if [ -f "${LINUX_PATCH_OFFB_SETCOLREG}" ]; then
				echo "Patching kernel to fix a bug in offb_setcolreg. Please wait..."
				patch -p1 < ${LINUX_PATCH_OFFB_SETCOLREG}
			fi
			cd ${MY_DIR}
		fi

		echo "Building Linux kernel (${VMLINUX}). Please wait..."
		make -j ${NUM_PROCESSORS} -C linux-${LINUX_VERSION} ${VMLINUX} ARCH=powerpc CROSS_COMPILE=${POWERPC_CROSS_COMPILER_PREFIX}/bin/${TARGET}- V=1
		if [ $? -ne 0 ]; then
			echo "Building Linux kernel (${VMLINUX}) failed"
			exit 255
		fi
		cp -f ${MY_DIR}/linux-${LINUX_VERSION}/${VMLINUX} ${MY_DIR}
		;;
	clean)
		echo "Cleaning Linux kernel (${VMLINUX}). Please wait..."
		rm -rf ${MY_DIR}/linux-${LINUX_VERSION}
		rm -f ${VMLINUX}
		;;
esac

################################################################################
#                                    BUSYBOX                                   #
################################################################################

case "${CMD}" in
	all)
		if [ ! -e ${TARBALLS_DIR}/busybox-${BUSYBOX_VERSION}.tar.bz2 ]; then
			echo "Downloading Busybox source tarball. Please wait..."
			wget --random-wait  --user-agent="Mozilla 5.0" http://www.busybox.net/downloads/busybox-${BUSYBOX_VERSION}.tar.bz2 -P ${TARBALLS_DIR}
			if [ $? -ne 0 ]; then
				echo "Downloading Busybox source tarball failed"
				exit 255
			fi
		fi

		BUSYBOX_CONFIG=${MY_DIR}/config/busybox-${BUSYBOX_VERSION}-config
		BUSYBOX_PATCH_LIBBB=${MY_DIR}/patches/patch-libbb-${BUSYBOX_VERSION}

		if [ ! -d busybox-${BUSYBOX_VERSION} ]; then
			echo "Uncompressing Busybox source tarball. Please wait..."
			tar jxvf ${TARBALLS_DIR}/busybox-${BUSYBOX_VERSION}.tar.bz2
			
			if [ -e "${BUSYBOX_PATCH_LIBBB}" ]; then
				echo "Patching libbb. Please wait..."
				cd ${MY_DIR}/busybox-${BUSYBOX_VERSION}
				patch -p1 < ${BUSYBOX_PATCH_LIBBB} || exit 255
			fi
			
			cd ${MY_DIR}
		fi

		echo "Building Busybox. Please wait..."
		cat ${BUSYBOX_CONFIG} | sed -e "s#\(CONFIG_CROSS_COMPILER_PREFIX=\).*\$#\1\"${POWERPC_CROSS_COMPILER_PREFIX}/bin/${TARGET}-\"#" -e "s#\(CONFIG_PREFIX=\).*\$#\1\"${INITRD_DIR}\"#" > busybox-${BUSYBOX_VERSION}/.config
		make -j ${NUM_PROCESSORS} -C busybox-${BUSYBOX_VERSION} busybox V=1
		if [ $? -ne 0 ]; then
			echo "Building Busybox failed"
			exit 255
		fi
		;;
	clean)
		echo "Cleaning Busybox. Please wait..."
		rm -rf busybox-${BUSYBOX_VERSION}
		;;
esac

################################################################################
#                                   GENEXT2FS                                  #
################################################################################

case "${CMD}" in
	all)
		if [ ! -e ${TARBALLS_DIR}/genext2fs-${GENEXT2FS_VERSION}.tar.gz ]; then
			echo "Downloading genext2fs source tarball. Please wait..."
			wget --random-wait  --user-agent="Mozilla 5.0" http://downloads.sourceforge.net/genext2fs/genext2fs-${GENEXT2FS_VERSION}.tar.gz -P ${TARBALLS_DIR}
			if [ $? -ne 0 ]; then
				echo "Downloading genext2fs source tarball failed"
				exit 255
			fi
		fi
		if [ ! -d genext2fs-${GENEXT2FS_VERSION} ]; then
			echo "Uncompressing genext2fs source tarball. Please wait..."
			tar zxvf ${TARBALLS_DIR}/genext2fs-${GENEXT2FS_VERSION}.tar.gz
		fi
		echo "Building genext2fs. Please wait..."
		cd "genext2fs-${GENEXT2FS_VERSION}"
		./configure
		if [ $? -ne 0 ]; then
			echo "Configuring genext2fs failed"
			exit 255
		fi
		make
		if [ $? -ne 0 ]; then
			echo "Building genext2fs failed"
			exit 255
		fi
		cd "${MY_DIR}"
		GENEXT2FS="${MY_DIR}/genext2fs-${GENEXT2FS_VERSION}/genext2fs"
		;;
	clean)
		echo "Cleaning genext2fs. Please wait..."
		rm -rf genext2fs-${GENEXT2FS_VERSION}
		;;
esac

################################################################################
#                                    INITRD                                    #
################################################################################

MakeInitRD ()
{
	local INITRD_IMG="$1"
	local INITRD_SIZE="$2"
	local INIT_SCRIPT="$3"
	local EXTRA_DIR="$4"
	local EXTRA_FILES="$5"

	rm -rf "${INITRD_DIR}" || exit 255
	mkdir -p ${INITRD_DIR} || exit 255

	echo "Creating initial ramdisk directory structure..."
	mkdir -p "${INITRD_DIR}/mnt" || exit 255
	mkdir -p "${INITRD_DIR}/sbin" || exit 255
	mkdir -p "${INITRD_DIR}/etc" || exit 255
	mkdir -p "${INITRD_DIR}/etc/init.d" || exit 255
	mkdir -p "${INITRD_DIR}/usr/bin" || exit 255
	mkdir -p "${INITRD_DIR}/usr" || exit 255
	mkdir -p "${INITRD_DIR}/usr/share" || exit 255
	mkdir -p "${INITRD_DIR}/bin" || exit 255
	mkdir -p "${INITRD_DIR}/sys" || exit 255
	mkdir -p "${INITRD_DIR}/dev" || exit 255
	mkdir -p "${INITRD_DIR}/proc" || exit 255
	mkdir -p "${INITRD_DIR}/lib" || exit 255
	mkdir -p "${INITRD_DIR}/lib/modules" || exit 255
	mkdir -p "${INITRD_DIR}/lib/modules/${LINUX_VERSION}" || exit 255
	mkdir -p "${INITRD_DIR}/lib/modules/${LINUX_VERSION}/kernel" || exit 255
	mkdir -p "${INITRD_DIR}/lib/modules/${LINUX_VERSION}/kernel/drivers" || exit 255
	mkdir -p "${INITRD_DIR}/lib/modules/${LINUX_VERSION}/kernel/drivers/misc" || exit 255
	mkdir -p "${INITRD_DIR}/tmp" || exit 255
	mkdir -p "${INITRD_DIR}/opt" || exit 255

	echo "Installing initialization scripts..."
	cp "${SCRIPTS_DIR}/rcS" "${INITRD_DIR}/etc/init.d" || exit 255
	cp "${SCRIPTS_DIR}/inittab" "${INITRD_DIR}/etc" || exit 255
	if [ -e "${SCRIPTS_DIR}/${INIT_SCRIPT}" ]; then
		cp "${SCRIPTS_DIR}/${INIT_SCRIPT}" "${INITRD_DIR}/etc/init.sh" || exit 255
	else
		cp "${SCRIPTS_DIR}/init.sh" "${INITRD_DIR}/etc/init.sh" || exit 255
	fi

	echo "Installing busybox into initial ramdisk..."
	make -C "busybox-${BUSYBOX_VERSION}" install || exit 255
	if [ $? -ne 0 ]; then
		echo "Installing Busybox failed"
		exit 255
	fi

	echo "Installing shared libraries into initial ramdisk..."
	for SO_FILE in libstdc++.so.6 libm.so.6 libgcc_s.so.1 libc.so.6 ld.so.1 libpthread.so.0 librt.so.1; do
		if [ -e "${POWERPC_CROSS_COMPILER_PREFIX}/powerpc-${CPU}-linux-gnu/sysroot/lib/${SO_FILE}" ]; then
			${POWERPC_CROSS_COMPILER_PREFIX}/bin/powerpc-${CPU}-linux-gnu-strip \
				--strip-unneeded -o "${INITRD_DIR}/lib/${SO_FILE}" \
				"${POWERPC_CROSS_COMPILER_PREFIX}/powerpc-${CPU}-linux-gnu/sysroot/lib/${SO_FILE}" || exit 255
		elif [ -e "${POWERPC_CROSS_COMPILER_PREFIX}/powerpc-${CPU}-linux-gnu/lib/${SO_FILE}" ]; then
			${POWERPC_CROSS_COMPILER_PREFIX}/bin/powerpc-${CPU}-linux-gnu-strip \
				--strip-unneeded -o "${INITRD_DIR}/lib/${SO_FILE}" \
				"${POWERPC_CROSS_COMPILER_PREFIX}/powerpc-${CPU}-linux-gnu/lib/${SO_FILE}" || exit 255
		else
			echo "${SO_FILE} not found"
			exit 255
		fi

		chmod +x "${INITRD_DIR}/lib/${SO_FILE}" || exit 255
	done

	cd "${INITRD_DIR}/lib"
	ln -s libstdc++.so.6 libstdc++.so || exit 255
	ln -s libm.so.6 libm.so || exit 255
	ln -s libgcc_s.so.1 libgcc_s.so || exit 255
	ln -s libc.so.6 libc.so || exit 255
	ln -s librt.so.1 librt.so || exit 255
	ln -s libpthread.so.0 libpthread.so || exit 255
	cd "${MY_DIR}"

	if [ -n "${EXTRA_DIR}" ]; then
		echo "Installing extra files into initial ramdisk"

		for EXTRA_FILE in ${EXTRA_FILES}; do
			echo "${EXTRA_DIR}/${EXTRA_FILE} -> /opt/${EXTRA_FILE}"
			mkdir -p "${INITRD_DIR}/opt/"$(dirname "${EXTRA_FILE}")

			EXTRA_FILE_HEAD=$(head -c 4 "${EXTRA_DIR}/${EXTRA_FILE}")
			EXTRA_ELF_HEAD=$(echo -e "\0177ELF")
			if [ "${EXTRA_FILE_HEAD}" = "${EXTRA_ELF_HEAD}" ]; then
				echo "Stripping /opt/${EXTRA_FILE}"
				${POWERPC_CROSS_COMPILER_PREFIX}/bin/powerpc-${CPU}-linux-gnu-strip \
					--strip-unneeded -o "${INITRD_DIR}/opt/${EXTRA_FILE}" \
					"${EXTRA_DIR}/${EXTRA_FILE}" || exit 255
				chmod +x "${INITRD_DIR}/opt/${EXTRA_FILE}" || exit 255
			else
				cp -f "${EXTRA_DIR}/${EXTRA_FILE}" "${INITRD_DIR}/opt/${EXTRA_FILE}" || exit 255
			fi
		done
	fi

	echo "Creating initial ramdisk image of ${INITRD_SIZE} KB with ext2fs root file system"
	${GENEXT2FS} -b "${INITRD_SIZE}" -d "${INITRD_DIR}" -D "config/device_table.txt" -m 0 -e 0 -i 1024 -U -f "${INITRD_IMG}"
	if [ $? -ne 0 ]; then
		echo "genext2fs failed"
		exit 255
	fi
	
	rm -rf "${INITRD_DIR}"
}

case "${CMD}" in
	all)
		MakeInitRD ${INITRD_IMG} 16384 init.sh '' ''

		MakeInitRD initrd_security_sha_small.img 8192 init_security_sha_small.sh "${MIBENCH_BUILD_DIR}" \
		"security/sha/runme_small.sh \
		security/sha/sha \
		security/sha/input_small.asc \
		"

		MakeInitRD initrd_security_sha_large.img 16384 init_security_sha_large.sh "${MIBENCH_BUILD_DIR}" \
		"security/sha/sha \
		security/sha/runme_large.sh \
		security/sha/input_large.asc \
		"

		MakeInitRD initrd_security_blowfish_small.img 8192 init_security_blowfish_small.sh "${MIBENCH_BUILD_DIR}" \
		"security/blowfish/runme_small.sh \
		security/blowfish/bf \
		security/blowfish/input_small.asc \
		"

		MakeInitRD initrd_security_blowfish_large.img 24576 init_security_blowfish_large.sh "${MIBENCH_BUILD_DIR}" \
		"security/blowfish/bf \
		security/blowfish/runme_large.sh \
		security/blowfish/input_large.asc \
		"

		MakeInitRD initrd_security_rijndael_small.img 8192 init_security_rijndael_small.sh "${MIBENCH_BUILD_DIR}" \
		"security/rijndael/runme_small.sh \
		security/rijndael/rijndael \
		security/rijndael/input_small.asc \
		"

		MakeInitRD initrd_security_rijndael_large.img 24576 init_security_rijndael_large.sh "${MIBENCH_BUILD_DIR}" \
		"security/rijndael/rijndael \
		security/rijndael/runme_large.sh \
		security/rijndael/input_large.asc \
		"

		MakeInitRD initrd_security_pgp.img 8192 init_security_pgp.sh "${MIBENCH_BUILD_DIR}" \
		"security/pgp/runme.sh \
		security/pgp/src/pgp \
		security/pgp/tests/config.txt \
		security/pgp/tests/PGPMacBinaryMappings.txt \
		security/pgp/tests/pubring.bak \
		security/pgp/tests/randseed.bin \
		security/pgp/tests/secring.pgp \
		security/pgp/tests/testin.txt \
		security/pgp/tests/testout.txt.asc \
		security/pgp/tests/PGPgroup.pgr \
		security/pgp/tests/PGPsdkPreferences \
		security/pgp/tests/pubring.pgp \
		security/pgp/tests/randseed.rnd \
		security/pgp/tests/secring.bak \
		security/pgp/tests/secring.skr \
		"

		MakeInitRD initrd_automotive_qsort_small.img 8192 init_automotive_qsort_small.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/qsort/runme_small.sh \
		automotive/qsort/qsort_small \
		automotive/qsort/input_small.dat \
		"

		MakeInitRD initrd_automotive_qsort_large.img 12288 init_automotive_qsort_large.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/qsort/runme_large.sh \
		automotive/qsort/qsort_large \
		automotive/qsort/input_large.dat \
		"

		MakeInitRD initrd_automotive_susan_small.img 8192 init_automotive_susan_small.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/susan/runme_small.sh \
		automotive/susan/susan \
		automotive/susan/input_small.pgm \
		"

		MakeInitRD initrd_automotive_susan_large.img 8192 init_automotive_susan_large.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/susan/susan \
		automotive/susan/runme_large.sh \
		automotive/susan/input_large.pgm \
		"

		MakeInitRD initrd_automotive_basicmath_small.img 8192 init_automotive_basicmath_small.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/basicmath/runme_small.sh \
		automotive/basicmath/basicmath_small \
		"

		MakeInitRD initrd_automotive_basicmath_large.img 24576 init_automotive_basicmath_large.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/basicmath/runme_large.sh \
		automotive/basicmath/basicmath_large \
		"

		MakeInitRD initrd_automotive_bitcount_small.img 8192 init_automotive_bitcount_small.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/bitcount/runme_small.sh \
		automotive/bitcount/bitcnts \
		"

		MakeInitRD initrd_automotive_bitcount_large.img 12288 init_automotive_bitcount_large.sh "${MIBENCH_BUILD_DIR}" \
		"automotive/bitcount/bitcnts \
		automotive/bitcount/runme_large.sh \
		"

		MakeInitRD initrd_network_dijkstra_small.img 8192 init_network_dijkstra_small.sh "${MIBENCH_BUILD_DIR}" \
		"network/dijkstra/runme_small.sh \
		network/dijkstra/dijkstra_small \
		network/dijkstra/input.dat \
		"

		MakeInitRD initrd_network_dijkstra_large.img 8192 init_network_dijkstra_large.sh "${MIBENCH_BUILD_DIR}" \
		"network/dijkstra/input.dat \
		network/dijkstra/runme_large.sh \
		network/dijkstra/dijkstra_large \
		"

		MakeInitRD initrd_network_patricia_small.img 8192 init_network_patricia_small.sh "${MIBENCH_BUILD_DIR}" \
		"network/patricia/runme_small.sh \
		network/patricia/patricia \
		network/patricia/small.udp \
		"

		MakeInitRD initrd_network_patricia_large.img 12288 init_network_patricia_large.sh "${MIBENCH_BUILD_DIR}" \
		"network/patricia/patricia \
		network/patricia/runme_large.sh \
		network/patricia/large.udp \
		"

		MakeInitRD initrd_telecomm_fft_small.img 8192 init_telecomm_fft_small.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/FFT/runme_small.sh \
		telecomm/FFT/fft \
		"

		MakeInitRD initrd_telecomm_fft_large.img 8192 init_telecomm_fft_large.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/FFT/fft \
		telecomm/FFT/runme_large.sh \
		"

		MakeInitRD initrd_telecomm_gsm_small.img 8192 init_telecomm_gsm_small.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/gsm/runme_small.sh \
		telecomm/gsm/bin/toast \
		telecomm/gsm/bin/untoast \
		telecomm/gsm/data/small.au \
		telecomm/gsm/data/small.au.run.gsm \
		"

		MakeInitRD initrd_telecomm_gsm_large.img 12288 init_telecomm_gsm_large.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/gsm/bin/toast \
		telecomm/gsm/bin/untoast \
		telecomm/gsm/runme_large.sh \
		telecomm/gsm/data/large.au \
		telecomm/gsm/data/large.au.run.gsm \
		"

		MakeInitRD initrd_telecomm_crc32_small.img 8192 init_telecomm_crc32_small.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/CRC32/runme_small.sh \
		telecomm/CRC32/crc \
		telecomm/adpcm/data/small.pcm \
		"

		MakeInitRD initrd_telecomm_crc32_large.img 40960 init_telecomm_crc32_large.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/CRC32/crc \
		telecomm/CRC32/runme_large.sh \
		telecomm/adpcm/data/large.pcm \
		"

		MakeInitRD initrd_telecomm_adpcm_small.img 12288 init_telecomm_adpcm_small.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/adpcm/runme_small.sh \
		telecomm/adpcm/bin/rawcaudio \
		telecomm/adpcm/bin/rawdaudio \
		telecomm/adpcm/data/small.pcm \
		telecomm/adpcm/data/small.adpcm \
		"

		MakeInitRD initrd_telecomm_adpcm_large.img 98304 init_telecomm_adpcm_large.sh "${MIBENCH_BUILD_DIR}" \
		"telecomm/adpcm/bin/rawcaudio \
		telecomm/adpcm/bin/rawdaudio \
		telecomm/adpcm/runme_large.sh \
		telecomm/adpcm/data/large.pcm \
		telecomm/adpcm/data/large.adpcm \
		"

		MakeInitRD initrd_consumer_typeset_small.img 12288 init_consumer_typeset_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/typeset/runme_small.sh \
		consumer/typeset/small.lout \
		consumer/typeset/lout-3.24/lout \
		consumer/typeset/lout-3.24/include/tbl \
		consumer/typeset/lout-3.24/include/eiffel \
		consumer/typeset/lout-3.24/include/bsf \
		consumer/typeset/lout-3.24/include/modulaf \
		consumer/typeset/lout-3.24/include/pasf \
		consumer/typeset/lout-3.24/include/slides \
		consumer/typeset/lout-3.24/include/bookf \
		consumer/typeset/lout-3.24/include/graphf \
		consumer/typeset/lout-3.24/include/report \
		consumer/typeset/lout-3.24/include/pythonf \
		consumer/typeset/lout-3.24/include/tabf.lpg \
		consumer/typeset/lout-3.24/include/figf \
		consumer/typeset/lout-3.24/include/pod \
		consumer/typeset/lout-3.24/include/diagf.lpg \
		consumer/typeset/lout-3.24/include/figf.lpg \
		consumer/typeset/lout-3.24/include/mydefs \
		consumer/typeset/lout-3.24/include/russian \
		consumer/typeset/lout-3.24/include/cprint \
		consumer/typeset/lout-3.24/include/diagf \
		consumer/typeset/lout-3.24/include/eq \
		consumer/typeset/lout-3.24/include/reportf \
		consumer/typeset/lout-3.24/include/python \
		consumer/typeset/lout-3.24/include/cprintf \
		consumer/typeset/lout-3.24/include/modula \
		consumer/typeset/lout-3.24/include/tblf.lpg \
		consumer/typeset/lout-3.24/include/langdefs \
		consumer/typeset/lout-3.24/include/book \
		consumer/typeset/lout-3.24/include/diagf.etc \
		consumer/typeset/lout-3.24/include/tabf \
		consumer/typeset/lout-3.24/include/perlf \
		consumer/typeset/lout-3.24/include/podf \
		consumer/typeset/lout-3.24/include/perl \
		consumer/typeset/lout-3.24/include/ts \
		consumer/typeset/lout-3.24/include/eqf \
		consumer/typeset/lout-3.24/include/slidesf \
		consumer/typeset/lout-3.24/include/russian.fd \
		consumer/typeset/lout-3.24/include/picture \
		consumer/typeset/lout-3.24/include/doc \
		consumer/typeset/lout-3.24/include/docf \
		consumer/typeset/lout-3.24/include/bsf.lpg \
		consumer/typeset/lout-3.24/include/fig \
		consumer/typeset/lout-3.24/include/tblf \
		consumer/typeset/lout-3.24/include/blue \
		consumer/typeset/lout-3.24/include/README \
		consumer/typeset/lout-3.24/include/eiffelf \
		consumer/typeset/lout-3.24/include/graphf.lpg \
		consumer/typeset/lout-3.24/include/tab \
		consumer/typeset/lout-3.24/include/picturef \
		consumer/typeset/lout-3.24/include/init \
		consumer/typeset/lout-3.24/include/dsf \
		consumer/typeset/lout-3.24/include/pas \
		consumer/typeset/lout-3.24/include/bluef \
		consumer/typeset/lout-3.24/include/latin2 \
		consumer/typeset/lout-3.24/include/graphf.etc \
		consumer/typeset/lout-3.24/include/graph \
		consumer/typeset/lout-3.24/include/diag \
		consumer/typeset/lout-3.24/data/loutrefs.li \
		consumer/typeset/lout-3.24/data/fontdefs.li \
		consumer/typeset/lout-3.24/data/latin2.ld \
		consumer/typeset/lout-3.24/data/loutrefs.ld \
		consumer/typeset/lout-3.24/data/fcvt \
		consumer/typeset/lout-3.24/data/refstyle.ld \
		consumer/typeset/lout-3.24/data/standard.li \
		consumer/typeset/lout-3.24/data/fontdefs.ld \
		consumer/typeset/lout-3.24/data/standard.ld \
		consumer/typeset/lout-3.24/data/README \
		consumer/typeset/lout-3.24/data/refstyle.li \
		consumer/typeset/lout-3.24/data/oldrefs.ld \
		consumer/typeset/lout-3.24/data/fcvt.awk \
		consumer/typeset/lout-3.24/font/He-NrBdO+ \
		consumer/typeset/lout-3.24/font/ZC-Rm+ \
		consumer/typeset/lout-3.24/font/He-NrO+ \
		consumer/typeset/lout-3.24/font/Symbol \
		consumer/typeset/lout-3.24/font/Bk-MdIt \
		consumer/typeset/lout-3.24/font/He-BdO \
		consumer/typeset/lout-3.24/font/Cr-O+ \
		consumer/typeset/lout-3.24/font/Cr-O \
		consumer/typeset/lout-3.24/font/Pa-BdF \
		consumer/typeset/lout-3.24/font/Ti-BdSC+ \
		consumer/typeset/lout-3.24/font/AG-BdO+ \
		consumer/typeset/lout-3.24/font/Ti-RmSC \
		consumer/typeset/lout-3.24/font/He-Bl+ \
		consumer/typeset/lout-3.24/font/He-CnBd \
		consumer/typeset/lout-3.24/font/He-CnBlO \
		consumer/typeset/lout-3.24/font/AG-CnMd \
		consumer/typeset/lout-3.24/font/Bk-Dm+ \
		consumer/typeset/lout-3.24/font/Ti-BdItF \
		consumer/typeset/lout-3.24/font/Ti-Sm+ \
		consumer/typeset/lout-3.24/font/He-NrBd+ \
		consumer/typeset/lout-3.24/font/Ti-It+ \
		consumer/typeset/lout-3.24/font/Bk-BdIt+ \
		consumer/typeset/lout-3.24/font/He-Bl \
		consumer/typeset/lout-3.24/font/He-O+ \
		consumer/typeset/lout-3.24/font/Pa-Bd+ \
		consumer/typeset/lout-3.24/font/He-ExtC \
		consumer/typeset/lout-3.24/font/He-O \
		consumer/typeset/lout-3.24/font/AG-CnDm+ \
		consumer/typeset/lout-3.24/font/Bk-Dm \
		consumer/typeset/lout-3.24/font/ZC-Lt+ \
		consumer/typeset/lout-3.24/font/He-Bd \
		consumer/typeset/lout-3.24/font/He-CnLiO \
		consumer/typeset/lout-3.24/font/Ti-Rm \
		consumer/typeset/lout-3.24/font/He-Cm \
		consumer/typeset/lout-3.24/font/AG-Dm+ \
		consumer/typeset/lout-3.24/font/ZC-Bd+ \
		consumer/typeset/lout-3.24/font/Pa-Rm+ \
		consumer/typeset/lout-3.24/font/AG-CnDm \
		consumer/typeset/lout-3.24/font/He-Lt \
		consumer/typeset/lout-3.24/font/AG-DmO+ \
		consumer/typeset/lout-3.24/font/NCS-It+ \
		consumer/typeset/lout-3.24/font/Bk-MdIt+ \
		consumer/typeset/lout-3.24/font/AG-ExLt \
		consumer/typeset/lout-3.24/font/He-CnO+ \
		consumer/typeset/lout-3.24/font/He-CnBl \
		consumer/typeset/lout-3.24/font/He-Cn+ \
		consumer/typeset/lout-3.24/font/He-CnLiO+ \
		consumer/typeset/lout-3.24/font/NCS-Bd \
		consumer/typeset/lout-3.24/font/ZC-Bd \
		consumer/typeset/lout-3.24/font/Ti-ExBd \
		consumer/typeset/lout-3.24/font/ZC-LtIt+ \
		consumer/typeset/lout-3.24/font/He-CnBdO \
		consumer/typeset/lout-3.24/font/He-CnBdO+ \
		consumer/typeset/lout-3.24/font/NCS-It \
		consumer/typeset/lout-3.24/font/AG-Bk \
		consumer/typeset/lout-3.24/font/He-NrBd \
		consumer/typeset/lout-3.24/font/He-CnBl+ \
		consumer/typeset/lout-3.24/font/Ti-Bd+ \
		consumer/typeset/lout-3.24/font/Pa-Rm \
		consumer/typeset/lout-3.24/font/Ti-Sm \
		consumer/typeset/lout-3.24/font/He-Cm+ \
		consumer/typeset/lout-3.24/font/ZD \
		consumer/typeset/lout-3.24/font/He-CnO \
		consumer/typeset/lout-3.24/font/He-Cn \
		consumer/typeset/lout-3.24/font/Ti-RmSC+ \
		consumer/typeset/lout-3.24/font/He-Nr+ \
		consumer/typeset/lout-3.24/font/Bk-DmIt+ \
		consumer/typeset/lout-3.24/font/AG-Dm \
		consumer/typeset/lout-3.24/font/Pa-BdF+ \
		consumer/typeset/lout-3.24/font/Ti-BdIt+ \
		consumer/typeset/lout-3.24/font/Pa-It \
		consumer/typeset/lout-3.24/font/He-CnLi \
		consumer/typeset/lout-3.24/font/ZC-Dm+ \
		consumer/typeset/lout-3.24/font/Ti-It \
		consumer/typeset/lout-3.24/font/Ti-ItF+ \
		consumer/typeset/lout-3.24/font/AG-BkO \
		consumer/typeset/lout-3.24/font/AG-CnBd+ \
		consumer/typeset/lout-3.24/font/Ti-BdSC \
		consumer/typeset/lout-3.24/font/AG-MdO+ \
		consumer/typeset/lout-3.24/font/ZC-LtIt \
		consumer/typeset/lout-3.24/font/Cr-Bd+ \
		consumer/typeset/lout-3.24/font/NCS-Rm+ \
		consumer/typeset/lout-3.24/font/Pa-BdIt \
		consumer/typeset/lout-3.24/font/ZC-It \
		consumer/typeset/lout-3.24/font/Ti-ExBd+ \
		consumer/typeset/lout-3.24/font/00README \
		consumer/typeset/lout-3.24/font/Cr+ \
		consumer/typeset/lout-3.24/font/Ti-BdItF+ \
		consumer/typeset/lout-3.24/font/He-UlCm \
		consumer/typeset/lout-3.24/font/He \
		consumer/typeset/lout-3.24/font/AG-ExLtO \
		consumer/typeset/lout-3.24/font/He-ExtC+ \
		consumer/typeset/lout-3.24/font/He-CnBlO+ \
		consumer/typeset/lout-3.24/font/AG-BdO \
		consumer/typeset/lout-3.24/font/ZC-Lt \
		consumer/typeset/lout-3.24/font/AG-Bk+ \
		consumer/typeset/lout-3.24/font/Pa-BdItF+ \
		consumer/typeset/lout-3.24/font/ZC-Rm \
		consumer/typeset/lout-3.24/font/AG-Bd \
		consumer/typeset/lout-3.24/font/Ti-SmIt \
		consumer/typeset/lout-3.24/font/Bk-Bd \
		consumer/typeset/lout-3.24/font/AG-CnBk \
		consumer/typeset/lout-3.24/font/AG-DmO \
		consumer/typeset/lout-3.24/font/He-Nr \
		consumer/typeset/lout-3.24/font/AG-Md+ \
		consumer/typeset/lout-3.24/font/AG-ExLt+ \
		consumer/typeset/lout-3.24/font/He-LtO \
		consumer/typeset/lout-3.24/font/Cr-BdO \
		consumer/typeset/lout-3.24/font/Pa-It+ \
		consumer/typeset/lout-3.24/font/NCS-Rm \
		consumer/typeset/lout-3.24/font/AG-MdO \
		consumer/typeset/lout-3.24/font/Bk-Lt \
		consumer/typeset/lout-3.24/font/He-Lt+ \
		consumer/typeset/lout-3.24/font/ZC-MdIt \
		consumer/typeset/lout-3.24/font/Cr-Bd \
		consumer/typeset/lout-3.24/font/Bk-BdIt \
		consumer/typeset/lout-3.24/font/Bk-Bd+ \
		consumer/typeset/lout-3.24/font/ZC-MdIt+ \
		consumer/typeset/lout-3.24/font/Pa-Bd \
		consumer/typeset/lout-3.24/font/ZC-Dm \
		consumer/typeset/lout-3.24/font/Cr-BdO+ \
		consumer/typeset/lout-3.24/font/Pa-SC+ \
		consumer/typeset/lout-3.24/font/Ti-BdIt \
		consumer/typeset/lout-3.24/font/Bk-Md \
		consumer/typeset/lout-3.24/font/He-BlO \
		consumer/typeset/lout-3.24/font/Bk-LtIt+ \
		consumer/typeset/lout-3.24/font/Ti-Bd \
		consumer/typeset/lout-3.24/font/AG-ExLtO+ \
		consumer/typeset/lout-3.24/font/Pa-BdItF \
		consumer/typeset/lout-3.24/font/He-Bd+ \
		consumer/typeset/lout-3.24/font/AG-BkO+ \
		consumer/typeset/lout-3.24/font/ZC-It+ \
		consumer/typeset/lout-3.24/font/He-CnLi+ \
		consumer/typeset/lout-3.24/font/He-UlCm+ \
		consumer/typeset/lout-3.24/font/Bk-LtIt \
		consumer/typeset/lout-3.24/font/Bk-Lt+ \
		consumer/typeset/lout-3.24/font/Ti-SmIt+ \
		consumer/typeset/lout-3.24/font/He-NrO \
		consumer/typeset/lout-3.24/font/He-BdO+ \
		consumer/typeset/lout-3.24/font/Cr \
		consumer/typeset/lout-3.24/font/Bk-Md+ \
		consumer/typeset/lout-3.24/font/He-LtO+ \
		consumer/typeset/lout-3.24/font/Pa-ItF+ \
		consumer/typeset/lout-3.24/font/AG-CnMd+ \
		consumer/typeset/lout-3.24/font/He+ \
		consumer/typeset/lout-3.24/font/AG-CnBk+ \
		consumer/typeset/lout-3.24/font/Pa-ItF \
		consumer/typeset/lout-3.24/font/AG-CnBd \
		consumer/typeset/lout-3.24/font/Ti-Rm+ \
		consumer/typeset/lout-3.24/font/NCS-BdIt \
		consumer/typeset/lout-3.24/font/Bk-DmIt \
		consumer/typeset/lout-3.24/font/He-BlO+ \
		consumer/typeset/lout-3.24/font/AG-Bd+ \
		consumer/typeset/lout-3.24/font/He-NrBdO \
		consumer/typeset/lout-3.24/font/Pa-SC \
		consumer/typeset/lout-3.24/font/NCS-BdIt+ \
		consumer/typeset/lout-3.24/font/Ti-ItF \
		consumer/typeset/lout-3.24/font/AG-Md \
		consumer/typeset/lout-3.24/font/Pa-BdIt+ \
		consumer/typeset/lout-3.24/font/NCS-Bd+ \
		consumer/typeset/lout-3.24/font/He-CnBd+ \
		consumer/typeset/lout-3.24/maps/null.LCM \
		consumer/typeset/lout-3.24/maps/Std.LCM \
		consumer/typeset/lout-3.24/maps/Symb.LCM \
		consumer/typeset/lout-3.24/maps/Latin1.LCM \
		consumer/typeset/lout-3.24/maps/Ding.LCM \
		consumer/typeset/lout-3.24/maps/LtLatin1.LCM \
		consumer/typeset/lout-3.24/maps/00README \
		consumer/typeset/lout-3.24/maps/LtLatin2.LCM \
		consumer/typeset/lout-3.24/maps/koi8r.LCM \
		consumer/typeset/lout-3.24/hyph/finnish.lh \
		consumer/typeset/lout-3.24/hyph/norweg.lh \
		consumer/typeset/lout-3.24/hyph/slovenia.lh \
		consumer/typeset/lout-3.24/hyph/danish.lh \
		consumer/typeset/lout-3.24/hyph/spanish.lh \
		consumer/typeset/lout-3.24/hyph/dutch.lh \
		consumer/typeset/lout-3.24/hyph/english.lp \
		consumer/typeset/lout-3.24/hyph/italian.lh \
		consumer/typeset/lout-3.24/hyph/czech.lh \
		consumer/typeset/lout-3.24/hyph/german.lh \
		consumer/typeset/lout-3.24/hyph/swedish.lh \
		consumer/typeset/lout-3.24/hyph/portugal.lh \
		consumer/typeset/lout-3.24/hyph/polish.lh \
		consumer/typeset/lout-3.24/hyph/README \
		consumer/typeset/lout-3.24/hyph/engluk.lh \
		consumer/typeset/lout-3.24/hyph/russian.lh \
		consumer/typeset/lout-3.24/hyph/english.lh \
		consumer/typeset/lout-3.24/hyph/french.lh \
		"

		MakeInitRD initrd_consumer_typeset_large.img 12288 init_consumer_typeset_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/typeset/lout-3.24/lout \
		consumer/typeset/runme_large.sh \
		consumer/typeset/large.lout \
		consumer/typeset/lout-3.24/include/tbl \
		consumer/typeset/lout-3.24/include/eiffel \
		consumer/typeset/lout-3.24/include/bsf \
		consumer/typeset/lout-3.24/include/modulaf \
		consumer/typeset/lout-3.24/include/pasf \
		consumer/typeset/lout-3.24/include/slides \
		consumer/typeset/lout-3.24/include/bookf \
		consumer/typeset/lout-3.24/include/graphf \
		consumer/typeset/lout-3.24/include/report \
		consumer/typeset/lout-3.24/include/pythonf \
		consumer/typeset/lout-3.24/include/tabf.lpg \
		consumer/typeset/lout-3.24/include/figf \
		consumer/typeset/lout-3.24/include/pod \
		consumer/typeset/lout-3.24/include/diagf.lpg \
		consumer/typeset/lout-3.24/include/figf.lpg \
		consumer/typeset/lout-3.24/include/mydefs \
		consumer/typeset/lout-3.24/include/russian \
		consumer/typeset/lout-3.24/include/cprint \
		consumer/typeset/lout-3.24/include/diagf \
		consumer/typeset/lout-3.24/include/eq \
		consumer/typeset/lout-3.24/include/reportf \
		consumer/typeset/lout-3.24/include/python \
		consumer/typeset/lout-3.24/include/cprintf \
		consumer/typeset/lout-3.24/include/modula \
		consumer/typeset/lout-3.24/include/tblf.lpg \
		consumer/typeset/lout-3.24/include/langdefs \
		consumer/typeset/lout-3.24/include/book \
		consumer/typeset/lout-3.24/include/diagf.etc \
		consumer/typeset/lout-3.24/include/tabf \
		consumer/typeset/lout-3.24/include/perlf \
		consumer/typeset/lout-3.24/include/podf \
		consumer/typeset/lout-3.24/include/perl \
		consumer/typeset/lout-3.24/include/ts \
		consumer/typeset/lout-3.24/include/eqf \
		consumer/typeset/lout-3.24/include/slidesf \
		consumer/typeset/lout-3.24/include/russian.fd \
		consumer/typeset/lout-3.24/include/picture \
		consumer/typeset/lout-3.24/include/doc \
		consumer/typeset/lout-3.24/include/docf \
		consumer/typeset/lout-3.24/include/bsf.lpg \
		consumer/typeset/lout-3.24/include/fig \
		consumer/typeset/lout-3.24/include/tblf \
		consumer/typeset/lout-3.24/include/blue \
		consumer/typeset/lout-3.24/include/README \
		consumer/typeset/lout-3.24/include/eiffelf \
		consumer/typeset/lout-3.24/include/graphf.lpg \
		consumer/typeset/lout-3.24/include/tab \
		consumer/typeset/lout-3.24/include/picturef \
		consumer/typeset/lout-3.24/include/init \
		consumer/typeset/lout-3.24/include/dsf \
		consumer/typeset/lout-3.24/include/pas \
		consumer/typeset/lout-3.24/include/bluef \
		consumer/typeset/lout-3.24/include/latin2 \
		consumer/typeset/lout-3.24/include/graphf.etc \
		consumer/typeset/lout-3.24/include/graph \
		consumer/typeset/lout-3.24/include/diag \
		consumer/typeset/lout-3.24/data/loutrefs.li \
		consumer/typeset/lout-3.24/data/fontdefs.li \
		consumer/typeset/lout-3.24/data/latin2.ld \
		consumer/typeset/lout-3.24/data/loutrefs.ld \
		consumer/typeset/lout-3.24/data/fcvt \
		consumer/typeset/lout-3.24/data/refstyle.ld \
		consumer/typeset/lout-3.24/data/standard.li \
		consumer/typeset/lout-3.24/data/fontdefs.ld \
		consumer/typeset/lout-3.24/data/standard.ld \
		consumer/typeset/lout-3.24/data/README \
		consumer/typeset/lout-3.24/data/refstyle.li \
		consumer/typeset/lout-3.24/data/oldrefs.ld \
		consumer/typeset/lout-3.24/data/fcvt.awk \
		consumer/typeset/lout-3.24/font/He-NrBdO+ \
		consumer/typeset/lout-3.24/font/ZC-Rm+ \
		consumer/typeset/lout-3.24/font/He-NrO+ \
		consumer/typeset/lout-3.24/font/Symbol \
		consumer/typeset/lout-3.24/font/Bk-MdIt \
		consumer/typeset/lout-3.24/font/He-BdO \
		consumer/typeset/lout-3.24/font/Cr-O+ \
		consumer/typeset/lout-3.24/font/Cr-O \
		consumer/typeset/lout-3.24/font/Pa-BdF \
		consumer/typeset/lout-3.24/font/Ti-BdSC+ \
		consumer/typeset/lout-3.24/font/AG-BdO+ \
		consumer/typeset/lout-3.24/font/Ti-RmSC \
		consumer/typeset/lout-3.24/font/He-Bl+ \
		consumer/typeset/lout-3.24/font/He-CnBd \
		consumer/typeset/lout-3.24/font/He-CnBlO \
		consumer/typeset/lout-3.24/font/AG-CnMd \
		consumer/typeset/lout-3.24/font/Bk-Dm+ \
		consumer/typeset/lout-3.24/font/Ti-BdItF \
		consumer/typeset/lout-3.24/font/Ti-Sm+ \
		consumer/typeset/lout-3.24/font/He-NrBd+ \
		consumer/typeset/lout-3.24/font/Ti-It+ \
		consumer/typeset/lout-3.24/font/Bk-BdIt+ \
		consumer/typeset/lout-3.24/font/He-Bl \
		consumer/typeset/lout-3.24/font/He-O+ \
		consumer/typeset/lout-3.24/font/Pa-Bd+ \
		consumer/typeset/lout-3.24/font/He-ExtC \
		consumer/typeset/lout-3.24/font/He-O \
		consumer/typeset/lout-3.24/font/AG-CnDm+ \
		consumer/typeset/lout-3.24/font/Bk-Dm \
		consumer/typeset/lout-3.24/font/ZC-Lt+ \
		consumer/typeset/lout-3.24/font/He-Bd \
		consumer/typeset/lout-3.24/font/He-CnLiO \
		consumer/typeset/lout-3.24/font/Ti-Rm \
		consumer/typeset/lout-3.24/font/He-Cm \
		consumer/typeset/lout-3.24/font/AG-Dm+ \
		consumer/typeset/lout-3.24/font/ZC-Bd+ \
		consumer/typeset/lout-3.24/font/Pa-Rm+ \
		consumer/typeset/lout-3.24/font/AG-CnDm \
		consumer/typeset/lout-3.24/font/He-Lt \
		consumer/typeset/lout-3.24/font/AG-DmO+ \
		consumer/typeset/lout-3.24/font/NCS-It+ \
		consumer/typeset/lout-3.24/font/Bk-MdIt+ \
		consumer/typeset/lout-3.24/font/AG-ExLt \
		consumer/typeset/lout-3.24/font/He-CnO+ \
		consumer/typeset/lout-3.24/font/He-CnBl \
		consumer/typeset/lout-3.24/font/He-Cn+ \
		consumer/typeset/lout-3.24/font/He-CnLiO+ \
		consumer/typeset/lout-3.24/font/NCS-Bd \
		consumer/typeset/lout-3.24/font/ZC-Bd \
		consumer/typeset/lout-3.24/font/Ti-ExBd \
		consumer/typeset/lout-3.24/font/ZC-LtIt+ \
		consumer/typeset/lout-3.24/font/He-CnBdO \
		consumer/typeset/lout-3.24/font/He-CnBdO+ \
		consumer/typeset/lout-3.24/font/NCS-It \
		consumer/typeset/lout-3.24/font/AG-Bk \
		consumer/typeset/lout-3.24/font/He-NrBd \
		consumer/typeset/lout-3.24/font/He-CnBl+ \
		consumer/typeset/lout-3.24/font/Ti-Bd+ \
		consumer/typeset/lout-3.24/font/Pa-Rm \
		consumer/typeset/lout-3.24/font/Ti-Sm \
		consumer/typeset/lout-3.24/font/He-Cm+ \
		consumer/typeset/lout-3.24/font/ZD \
		consumer/typeset/lout-3.24/font/He-CnO \
		consumer/typeset/lout-3.24/font/He-Cn \
		consumer/typeset/lout-3.24/font/Ti-RmSC+ \
		consumer/typeset/lout-3.24/font/He-Nr+ \
		consumer/typeset/lout-3.24/font/Bk-DmIt+ \
		consumer/typeset/lout-3.24/font/AG-Dm \
		consumer/typeset/lout-3.24/font/Pa-BdF+ \
		consumer/typeset/lout-3.24/font/Ti-BdIt+ \
		consumer/typeset/lout-3.24/font/Pa-It \
		consumer/typeset/lout-3.24/font/He-CnLi \
		consumer/typeset/lout-3.24/font/ZC-Dm+ \
		consumer/typeset/lout-3.24/font/Ti-It \
		consumer/typeset/lout-3.24/font/Ti-ItF+ \
		consumer/typeset/lout-3.24/font/AG-BkO \
		consumer/typeset/lout-3.24/font/AG-CnBd+ \
		consumer/typeset/lout-3.24/font/Ti-BdSC \
		consumer/typeset/lout-3.24/font/AG-MdO+ \
		consumer/typeset/lout-3.24/font/ZC-LtIt \
		consumer/typeset/lout-3.24/font/Cr-Bd+ \
		consumer/typeset/lout-3.24/font/NCS-Rm+ \
		consumer/typeset/lout-3.24/font/Pa-BdIt \
		consumer/typeset/lout-3.24/font/ZC-It \
		consumer/typeset/lout-3.24/font/Ti-ExBd+ \
		consumer/typeset/lout-3.24/font/00README \
		consumer/typeset/lout-3.24/font/Cr+ \
		consumer/typeset/lout-3.24/font/Ti-BdItF+ \
		consumer/typeset/lout-3.24/font/He-UlCm \
		consumer/typeset/lout-3.24/font/He \
		consumer/typeset/lout-3.24/font/AG-ExLtO \
		consumer/typeset/lout-3.24/font/He-ExtC+ \
		consumer/typeset/lout-3.24/font/He-CnBlO+ \
		consumer/typeset/lout-3.24/font/AG-BdO \
		consumer/typeset/lout-3.24/font/ZC-Lt \
		consumer/typeset/lout-3.24/font/AG-Bk+ \
		consumer/typeset/lout-3.24/font/Pa-BdItF+ \
		consumer/typeset/lout-3.24/font/ZC-Rm \
		consumer/typeset/lout-3.24/font/AG-Bd \
		consumer/typeset/lout-3.24/font/Ti-SmIt \
		consumer/typeset/lout-3.24/font/Bk-Bd \
		consumer/typeset/lout-3.24/font/AG-CnBk \
		consumer/typeset/lout-3.24/font/AG-DmO \
		consumer/typeset/lout-3.24/font/He-Nr \
		consumer/typeset/lout-3.24/font/AG-Md+ \
		consumer/typeset/lout-3.24/font/AG-ExLt+ \
		consumer/typeset/lout-3.24/font/He-LtO \
		consumer/typeset/lout-3.24/font/Cr-BdO \
		consumer/typeset/lout-3.24/font/Pa-It+ \
		consumer/typeset/lout-3.24/font/NCS-Rm \
		consumer/typeset/lout-3.24/font/AG-MdO \
		consumer/typeset/lout-3.24/font/Bk-Lt \
		consumer/typeset/lout-3.24/font/He-Lt+ \
		consumer/typeset/lout-3.24/font/ZC-MdIt \
		consumer/typeset/lout-3.24/font/Cr-Bd \
		consumer/typeset/lout-3.24/font/Bk-BdIt \
		consumer/typeset/lout-3.24/font/Bk-Bd+ \
		consumer/typeset/lout-3.24/font/ZC-MdIt+ \
		consumer/typeset/lout-3.24/font/Pa-Bd \
		consumer/typeset/lout-3.24/font/ZC-Dm \
		consumer/typeset/lout-3.24/font/Cr-BdO+ \
		consumer/typeset/lout-3.24/font/Pa-SC+ \
		consumer/typeset/lout-3.24/font/Ti-BdIt \
		consumer/typeset/lout-3.24/font/Bk-Md \
		consumer/typeset/lout-3.24/font/He-BlO \
		consumer/typeset/lout-3.24/font/Bk-LtIt+ \
		consumer/typeset/lout-3.24/font/Ti-Bd \
		consumer/typeset/lout-3.24/font/AG-ExLtO+ \
		consumer/typeset/lout-3.24/font/Pa-BdItF \
		consumer/typeset/lout-3.24/font/He-Bd+ \
		consumer/typeset/lout-3.24/font/AG-BkO+ \
		consumer/typeset/lout-3.24/font/ZC-It+ \
		consumer/typeset/lout-3.24/font/He-CnLi+ \
		consumer/typeset/lout-3.24/font/He-UlCm+ \
		consumer/typeset/lout-3.24/font/Bk-LtIt \
		consumer/typeset/lout-3.24/font/Bk-Lt+ \
		consumer/typeset/lout-3.24/font/Ti-SmIt+ \
		consumer/typeset/lout-3.24/font/He-NrO \
		consumer/typeset/lout-3.24/font/He-BdO+ \
		consumer/typeset/lout-3.24/font/Cr \
		consumer/typeset/lout-3.24/font/Bk-Md+ \
		consumer/typeset/lout-3.24/font/He-LtO+ \
		consumer/typeset/lout-3.24/font/Pa-ItF+ \
		consumer/typeset/lout-3.24/font/AG-CnMd+ \
		consumer/typeset/lout-3.24/font/He+ \
		consumer/typeset/lout-3.24/font/AG-CnBk+ \
		consumer/typeset/lout-3.24/font/Pa-ItF \
		consumer/typeset/lout-3.24/font/AG-CnBd \
		consumer/typeset/lout-3.24/font/Ti-Rm+ \
		consumer/typeset/lout-3.24/font/NCS-BdIt \
		consumer/typeset/lout-3.24/font/Bk-DmIt \
		consumer/typeset/lout-3.24/font/He-BlO+ \
		consumer/typeset/lout-3.24/font/AG-Bd+ \
		consumer/typeset/lout-3.24/font/He-NrBdO \
		consumer/typeset/lout-3.24/font/Pa-SC \
		consumer/typeset/lout-3.24/font/NCS-BdIt+ \
		consumer/typeset/lout-3.24/font/Ti-ItF \
		consumer/typeset/lout-3.24/font/AG-Md \
		consumer/typeset/lout-3.24/font/Pa-BdIt+ \
		consumer/typeset/lout-3.24/font/NCS-Bd+ \
		consumer/typeset/lout-3.24/font/He-CnBd+ \
		consumer/typeset/lout-3.24/maps/null.LCM \
		consumer/typeset/lout-3.24/maps/Std.LCM \
		consumer/typeset/lout-3.24/maps/Symb.LCM \
		consumer/typeset/lout-3.24/maps/Latin1.LCM \
		consumer/typeset/lout-3.24/maps/Ding.LCM \
		consumer/typeset/lout-3.24/maps/LtLatin1.LCM \
		consumer/typeset/lout-3.24/maps/00README \
		consumer/typeset/lout-3.24/maps/LtLatin2.LCM \
		consumer/typeset/lout-3.24/maps/koi8r.LCM \
		consumer/typeset/lout-3.24/hyph/finnish.lh \
		consumer/typeset/lout-3.24/hyph/norweg.lh \
		consumer/typeset/lout-3.24/hyph/slovenia.lh \
		consumer/typeset/lout-3.24/hyph/danish.lh \
		consumer/typeset/lout-3.24/hyph/spanish.lh \
		consumer/typeset/lout-3.24/hyph/dutch.lh \
		consumer/typeset/lout-3.24/hyph/english.lp \
		consumer/typeset/lout-3.24/hyph/italian.lh \
		consumer/typeset/lout-3.24/hyph/czech.lh \
		consumer/typeset/lout-3.24/hyph/german.lh \
		consumer/typeset/lout-3.24/hyph/swedish.lh \
		consumer/typeset/lout-3.24/hyph/portugal.lh \
		consumer/typeset/lout-3.24/hyph/polish.lh \
		consumer/typeset/lout-3.24/hyph/README \
		consumer/typeset/lout-3.24/hyph/engluk.lh \
		consumer/typeset/lout-3.24/hyph/russian.lh \
		consumer/typeset/lout-3.24/hyph/english.lh \
		consumer/typeset/lout-3.24/hyph/french.lh \
		"

		MakeInitRD initrd_consumer_lame_small.img 8192 init_consumer_lame_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/lame/runme_small.sh \
		consumer/lame/lame3.70/lame \
		consumer/lame/small.wav \
		"

		MakeInitRD initrd_consumer_lame_large.img 12288 init_consumer_lame_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/lame/lame3.70/lame \
		consumer/lame/runme_large.sh \
		consumer/lame/large.wav \
		"

		MakeInitRD initrd_consumer_mad_small.img 8192 init_consumer_mad_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/mad/runme_small.sh \
		consumer/mad/mad-0.14.2b/madplay \
		consumer/mad/small.mp3 \
		"

		MakeInitRD initrd_consumer_mad_large.img 12288 init_consumer_mad_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/mad/runme_large.sh \
		consumer/mad/mad-0.14.2b/madplay \
		consumer/mad/large.mp3 \
		"

		MakeInitRD initrd_consumer_tiffmedian_small.img 24576 init_consumer_tiffmedian_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiffmedian/runme_small.sh \
		consumer/tiff-v3.5.4/tools/tiffmedian \
		consumer/tiff-data/small.tif \
		"
		
		MakeInitRD initrd_consumer_tiffmedian_large.img 65536 init_consumer_tiffmedian_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiffmedian/runme_large.sh \
		consumer/tiff-v3.5.4/tools/tiffmedian \
		consumer/tiff-data/large.tif \
		"

		MakeInitRD initrd_consumer_tiffdither_small.img 12288 init_consumer_tiffdither_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiffdither/runme_small.sh \
		consumer/tiff-v3.5.4/tools/tiffdither \
		consumer/tiff-data/smallbw.tif \
		"
		
		MakeInitRD initrd_consumer_tiffdither_large.img 24576 init_consumer_tiffdither_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiffdither/runme_large.sh \
		consumer/tiff-v3.5.4/tools/tiffdither \
		consumer/tiff-data/largebw.tif \
		"

		MakeInitRD initrd_consumer_tiff2rgba_small.img 32768 init_consumer_tiff2rgba_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiff2rgba/runme_small.sh \
		consumer/tiff-v3.5.4/tools/tiff2rgba \
		consumer/tiff-data/small.tif \
		"
		
		MakeInitRD initrd_consumer_tiff2rgba_large.img 98304 init_consumer_tiff2rgba_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiff2rgba/runme_large.sh \
		consumer/tiff-v3.5.4/tools/tiff2rgba \
		consumer/tiff-data/large.tif \
		"

		MakeInitRD initrd_consumer_tiff2bw_small.img 16384 init_consumer_tiff2bw_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiff2bw/runme_small.sh \
		consumer/tiff-v3.5.4/tools/tiff2bw \
		consumer/tiff-data/small.tif \
		"
		
		MakeInitRD initrd_consumer_tiff2bw_large.img 65536 init_consumer_tiff2bw_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/tiff2bw/runme_large.sh \
		consumer/tiff-v3.5.4/tools/tiff2bw \
		consumer/tiff-data/large.tif \
		"

		MakeInitRD initrd_consumer_jpeg_small.img 8192 init_consumer_jpeg_small.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/jpeg/runme_small.sh \
		consumer/jpeg/jpeg-6a/cjpeg \
		consumer/jpeg/jpeg-6a/djpeg \
		consumer/jpeg/input_small.ppm \
		consumer/jpeg/input_small.jpg \
		"

		MakeInitRD initrd_consumer_jpeg_large.img 12288 init_consumer_jpeg_large.sh "${MIBENCH_BUILD_DIR}" \
		"consumer/jpeg/jpeg-6a/cjpeg \
		consumer/jpeg/jpeg-6a/djpeg \
		consumer/jpeg/runme_large.sh \
		consumer/jpeg/input_large.ppm \
		consumer/jpeg/input_large.jpg \
		"

		MakeInitRD initrd_office_stringsearch_small.img 8192 init_office_stringsearch_small.sh "${MIBENCH_BUILD_DIR}" \
		"office/stringsearch/runme_small.sh \
		office/stringsearch/search_small \
		"

		MakeInitRD initrd_office_stringsearch_large.img 8192 init_office_stringsearch_large.sh "${MIBENCH_BUILD_DIR}" \
		"office/stringsearch/runme_large.sh \
		office/stringsearch/search_large \
		"

		MakeInitRD initrd_office_sphinx.img 40960 init_office_sphinx.sh "${MIBENCH_BUILD_DIR}" \
		"office/sphinx/src/examples/sphinx2-continuous \
		office/sphinx/runme.sh \
		office/sphinx/model/hmm/6k/phone \
		office/sphinx/model/hmm/6k/map \
		office/sphinx/model/lm/turtle/turtle.dic \
		office/sphinx/model/lm/turtle/turtle.lm \
		office/sphinx/model/hmm/6k/+BREATH+.chmm \
		office/sphinx/model/hmm/6k/+COUGH+.chmm \
		office/sphinx/model/hmm/6k/+LAUGH+.chmm \
		office/sphinx/model/hmm/6k/+SMACK+.chmm \
		office/sphinx/model/hmm/6k/+UH+.chmm \
		office/sphinx/model/hmm/6k/+UHUM+.chmm \
		office/sphinx/model/hmm/6k/+UM+.chmm \
		office/sphinx/model/hmm/6k/SIL.chmm \
		office/sphinx/model/hmm/6k/AA.chmm \
		office/sphinx/model/hmm/6k/AE.chmm \
		office/sphinx/model/hmm/6k/AH.chmm \
		office/sphinx/model/hmm/6k/AO.chmm \
		office/sphinx/model/hmm/6k/AW.chmm \
		office/sphinx/model/hmm/6k/AX.chmm \
		office/sphinx/model/hmm/6k/AXR.chmm \
		office/sphinx/model/hmm/6k/AY.chmm \
		office/sphinx/model/hmm/6k/B.chmm \
		office/sphinx/model/hmm/6k/CH.chmm \
		office/sphinx/model/hmm/6k/D.chmm \
		office/sphinx/model/hmm/6k/DH.chmm \
		office/sphinx/model/hmm/6k/DX.chmm \
		office/sphinx/model/hmm/6k/EH.chmm \
		office/sphinx/model/hmm/6k/ER.chmm \
		office/sphinx/model/hmm/6k/EY.chmm \
		office/sphinx/model/hmm/6k/F.chmm \
		office/sphinx/model/hmm/6k/G.chmm \
		office/sphinx/model/hmm/6k/HH.chmm \
		office/sphinx/model/hmm/6k/IH.chmm \
		office/sphinx/model/hmm/6k/IX.chmm \
		office/sphinx/model/hmm/6k/IY.chmm \
		office/sphinx/model/hmm/6k/JH.chmm \
		office/sphinx/model/hmm/6k/K.chmm \
		office/sphinx/model/hmm/6k/L.chmm \
		office/sphinx/model/hmm/6k/M.chmm \
		office/sphinx/model/hmm/6k/N.chmm \
		office/sphinx/model/hmm/6k/NG.chmm \
		office/sphinx/model/hmm/6k/OW.chmm \
		office/sphinx/model/hmm/6k/OY.chmm \
		office/sphinx/model/hmm/6k/P.chmm \
		office/sphinx/model/hmm/6k/R.chmm \
		office/sphinx/model/hmm/6k/S.chmm \
		office/sphinx/model/hmm/6k/SH.chmm \
		office/sphinx/model/hmm/6k/T.chmm \
		office/sphinx/model/hmm/6k/TH.chmm \
		office/sphinx/model/hmm/6k/UH.chmm \
		office/sphinx/model/hmm/6k/UW.chmm \
		office/sphinx/model/hmm/6k/V.chmm \
		office/sphinx/model/hmm/6k/W.chmm \
		office/sphinx/model/hmm/6k/Y.chmm \
		office/sphinx/model/hmm/6k/Z.chmm \
		office/sphinx/model/hmm/6k/ZH.chmm \
		office/sphinx/model/hmm/6k/sendump \
		office/sphinx/model/hmm/6k/cep.256.vec \
		office/sphinx/model/hmm/6k/cep.256.var \
		office/sphinx/model/hmm/6k/d2cep.256.vec \
		office/sphinx/model/hmm/6k/d2cep.256.var \
		office/sphinx/model/hmm/6k/p3cep.256.vec \
		office/sphinx/model/hmm/6k/p3cep.256.var \
		office/sphinx/model/hmm/6k/xcep.256.vec \
		office/sphinx/model/hmm/6k/xcep.256.var \
		office/sphinx/tests/FOO \
		office/sphinx/tests/bigtest.ctl \
		office/sphinx/tests/bigtest.16k \
		"
		
		MakeInitRD initrd_office_rsynth_small.img 8192 init_office_rsynth_small.sh "${MIBENCH_BUILD_DIR}" \
		"office/rsynth/runme_small.sh \
		office/rsynth/say \
		office/rsynth/smallinput.txt \
		"

		MakeInitRD initrd_office_rsynth_large.img 8192 init_office_rsynth_large.sh "${MIBENCH_BUILD_DIR}" \
		"office/rsynth/say \
		office/rsynth/runme_large.sh \
		office/rsynth/largeinput.txt \
		"
		;;
	clean)
		echo "Cleaning initial ramdisks. Please wait..."
		rm -f ${INITRD_IMG}.gz
		rm -f initrd_automotive_basicmath_large.img
		rm -f initrd_automotive_basicmath_small.img
		rm -f initrd_automotive_bitcount_large.img
		rm -f initrd_automotive_bitcount_small.img
		rm -f initrd_automotive_qsort_large.img
		rm -f initrd_automotive_qsort_small.img
		rm -f initrd_automotive_susan_large.img
		rm -f initrd_automotive_susan_small.img
		rm -f initrd_consumer_jpeg_large.img
		rm -f initrd_consumer_jpeg_small.img
		rm -f initrd_consumer_lame_large.img
		rm -f initrd_consumer_lame_small.img
		rm -f initrd_consumer_mad_large.img
		rm -f initrd_consumer_mad_small.img
		rm -f initrd_consumer_tiff2bw_large.img
		rm -f initrd_consumer_tiff2bw_small.img
		rm -f initrd_consumer_tiff2rgba_large.img
		rm -f initrd_consumer_tiff2rgba_small.img
		rm -f initrd_consumer_tiffdither_large.img
		rm -f initrd_consumer_tiffdither_small.img
		rm -f initrd_consumer_tiffmedian_large.img
		rm -f initrd_consumer_tiffmedian_small.img
		rm -f initrd_consumer_typeset_large.img
		rm -f initrd_consumer_typeset_small.img
		rm -f initrd_network_dijkstra_large.img
		rm -f initrd_network_dijkstra_small.img
		rm -f initrd_network_patricia_large.img
		rm -f initrd_network_patricia_small.img
		rm -f initrd_office_sphinx.img
		rm -f initrd_office_stringsearch_large.img
		rm -f initrd_office_stringsearch_small.img
		rm -f initrd_office_rsynth_large.img
		rm -f initrd_office_rsynth_small.img
		rm -f initrd_security_blowfish_large.img
		rm -f initrd_security_blowfish_small.img
		rm -f initrd_security_pgp.img
		rm -f initrd_security_rijndael_large.img
		rm -f initrd_security_rijndael_small.img
		rm -f initrd_security_sha_large.img
		rm -f initrd_security_sha_small.img
		rm -f initrd_telecomm_adpcm_large.img
		rm -f initrd_telecomm_adpcm_small.img
		rm -f initrd_telecomm_crc32_large.img
		rm -f initrd_telecomm_crc32_small.img
		rm -f initrd_telecomm_fft_large.img
		rm -f initrd_telecomm_fft_small.img
		rm -f initrd_telecomm_gsm_large.img
		rm -f initrd_telecomm_gsm_small.img
		;;
esac

case "${CMD}" in
	all)
		echo "Your Linux kernel is ready: ${VMLINUX}"
		echo "Your initial uncompressed ramdisk images are ready: ${INITRD_IMG} initrd_automotive_basicmath_large.img initrd_automotive_basicmath_small.img initrd_automotive_bitcount_large.img initrd_automotive_bitcount_small.img initrd_automotive_qsort_large.img initrd_automotive_qsort_small.img initrd_automotive_susan_large.img initrd_automotive_susan_small.img initrd_consumer_jpeg_large.img initrd_consumer_jpeg_small.img initrd_consumer_lame_large.img initrd_consumer_lame_small.img initrd_consumer_mad_large.img initrd_consumer_mad_small.img initrd_consumer_tiff2bw_large.img initrd_consumer_tiff2bw_small.img initrd_consumer_tiff2rgba_large.img initrd_consumer_tiff2rgba_small.img initrd_consumer_tiffdither_large.img initrd_consumer_tiffdither_small.img initrd_consumer_tiffmedian_large.img initrd_consumer_tiffmedian_small.img initrd_consumer_typeset_large.img initrd_consumer_typeset_small.img initrd.img initrd_network_dijkstra_large.img initrd_network_dijkstra_small.img initrd_network_patricia_large.img initrd_network_patricia_small.img initrd_office_sphinx.img initrd_office_stringsearch_large.img initrd_office_stringsearch_small.img initrd_security_blowfish_large.img initrd_security_blowfish_small.img initrd_security_pgp.img initrd_security_rijndael_large.img initrd_security_rijndael_small.img initrd_security_sha_large.img initrd_security_sha_small.img initrd_telecomm_adpcm_large.img initrd_telecomm_adpcm_small.img initrd_telecomm_crc32_large.img initrd_telecomm_crc32_small.img initrd_telecomm_fft_large.img initrd_telecomm_fft_small.img initrd_telecomm_gsm_large.img initrd_telecomm_gsm_small.img"
		;;
	clean)
		echo "Your build has been cleaned"
		;;
esac